/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { IPubSub } from "@fluidframework/server-memory-orderer";
import { IHistorian } from "@fluidframework/server-services-client";
import { ICheckpointRepository, IDatabaseManager, IDocumentRepository, IDocumentStorage, ILogger, IOrderer, IOrdererManager, IServiceConfiguration } from "@fluidframework/server-services-core";
/**
 * @internal
 */
export declare class LocalOrdererManager implements IOrdererManager {
    private readonly storage;
    private readonly databaseManager;
    private readonly createHistorian;
    private readonly logger;
    private readonly serviceConfiguration?;
    private readonly pubsub?;
    private readonly documentRepository?;
    private readonly checkpointRepository?;
    /**
     * Map of "tenantId/documentId" to the orderer for that document.
     */
    private readonly ordererMap;
    constructor(storage: IDocumentStorage, databaseManager: IDatabaseManager, createHistorian: (tenant: string) => Promise<IHistorian>, logger: ILogger, serviceConfiguration?: Partial<IServiceConfiguration> | undefined, pubsub?: IPubSub | undefined, documentRepository?: IDocumentRepository | undefined, checkpointRepository?: ICheckpointRepository | undefined);
    /**
     * Closes all local orderers
     */
    close(): Promise<void>;
    /**
     * Returns true if there are any received ops that are not yet ordered.
     */
    hasPendingWork(): Promise<boolean>;
    getOrderer(tenantId: string, documentId: string): Promise<IOrderer>;
    private createLocalOrderer;
}
//# sourceMappingURL=localOrdererManager.d.ts.map